@@ -28,9 +28,9 @@
 class SessionUiProxy : public KIMAP::SessionUiProxy
 {
 public:
-    bool ignoreSslError(const KSslErrorUiData &errorData) override {
-        if (KIO::SslUi::askIgnoreSslErrors(errorData, KIO::SslUi::RecallAndStoreRules))
-        {
+    bool ignoreSslError(const KSslErrorUiData &errorData) override
+    {
+        if (KIO::SslUi::askIgnoreSslErrors(errorData, KIO::SslUi::RecallAndStoreRules)) {
             return true;
         } else {
             return false;
