@@ -27,7 +27,7 @@
 
 #include <QObject>
 
-namespace KCalCore {
+namespace KCalendarCore {
 class FileStorage;
 }
 namespace Akonadi {
@@ -39,7 +39,7 @@ using namespace KAlarmCal;
 namespace KAlarmResourceCommon {
 void          initialise(QObject *parent);
 //    void          customizeConfigDialog(SingleFileResourceConfigDialog<Settings>*);
-KACalendar::Compat getCompatibility(const KCalCore::FileStorage::Ptr &, int &version);
+KACalendar::Compat getCompatibility(const KCalendarCore::FileStorage::Ptr &, int &version);
 Akonadi::Item retrieveItem(const Akonadi::Item &, KAEvent &);
 KAEvent       checkItemChanged(const Akonadi::Item &, QString &errorMsg);
 void          setCollectionCompatibility(const Akonadi::Collection &, KACalendar::Compat, int version);
