@@ -184,7 +184,7 @@ void SingleFileResourceBase::collectionChanged(const Akonadi::Collection &collec
 {
     const QString newName = collection.displayName();
     if (collection.hasAttribute<EntityDisplayAttribute>()) {
-        EntityDisplayAttribute *attr = collection.attribute<EntityDisplayAttribute>();
+        const EntityDisplayAttribute *attr = collection.attribute<EntityDisplayAttribute>();
         if (!attr->iconName().isEmpty()) {
             mCollectionIcon = attr->iconName();
         }
